@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 09:24:50
-@LastEditTime: 2021-09-14 19:42:10
+@LastEditTime: 2021-09-17 17:51:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -12,11 +12,13 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 
 
-class SkuInfoHandler(TaoBaseHandler):
+class SkuInfoHandler(ClientBaseHandler):
     """
     :description: 获取SKU信息
     """
     @filter_check_params("num_iid")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取SKU信息
@@ -24,7 +26,7 @@ class SkuInfoHandler(TaoBaseHandler):
         :return
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         num_iid = self.get_param("num_iid")
         is_log = bool(self.get_param("is_log", False))
 
@@ -48,10 +50,12 @@ class SkuInfoHandler(TaoBaseHandler):
             return self.response_json_success(sku_detail["items_seller_list_get_response"])
 
 
-class GoodsListHandler(TaoBaseHandler):
+class GoodsListHandler(ClientBaseHandler):
     """
     :description: 获取商品列表
     """
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取商品列表
@@ -60,7 +64,7 @@ class GoodsListHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = self.get_param("page_size", 10)
         is_log = bool(self.get_param("is_log", False))
