@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2021-09-28 13:44:04
+@LastEditTime: 2021-10-08 15:08:13
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -33,7 +33,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
         pay_order_no = self.get_param("pay_order_no")
         invoke_result_data = InvokeResultData()
 
-        if SevenHelper.is_continue_request(f"VoucherOrder_{str(user_id)}") == True:
+        if SevenHelper.is_continue_request(f"WechatVoucherOrderHandler_{str(user_id)}") == True:
             return self.response_json_error("error", "对不起,请求太频繁")
         pay_order_model = PayOrderModel(context=self)
         pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
@@ -47,10 +47,10 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
         # 金额
         total_fee = pay_order.pay_amount
         # ip
-        ip = SevenHelper.get_first_ip()
+        ip = SevenHelper.get_first_ip(self.get_remote_ip())
 
         try:
-            invoke_result_data = self.business_process_executing(self.request_params)
+            invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == True:
                 pay_notify_url = invoke_result_data.data["pay_notify_url"] if invoke_result_data.data.__contains__("pay_notify_url") else pay_notify_url
                 time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else str(SevenHelper.get_now_int(1))  #交易结束时间,设置1小时
@@ -59,16 +59,15 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
-            invoke_result_data = self.business_process_executed(invoke_result_data, self.request_params)
+            invoke_result_data = self.business_process_executed(invoke_result_data)
             return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
             self.logging_link_error("【创建微信预订单异常】" + str(ex))
             return self.response_json_error("fail", "请重新支付")
 
-    def business_process_executing(self, request_params):
+    def business_process_executing(self):
         """
         :description: 执行前事件
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -76,18 +75,17 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
         invoke_result_data.data = {}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data, request_params):
+    def business_process_executed(self, invoke_result_data):
         """
         :description: 执行后事件
         :param invoke_result_data: invoke_result_data
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
         return invoke_result_data
 
 
-class WechatPayNotifyHandler(ClientBaseHandler):
+class WechatPayNotifyHandler(FrameBaseHandler):
     """
     :description: 微信支付异步通知
     """
@@ -124,7 +122,7 @@ class WechatPayNotifyHandler(ClientBaseHandler):
                 self.logging_link_error(f"微信支付订单[{pay_order_no}] 金额不匹配疑似刷单.数据库金额:{str(pay_order.pay_amount)} 平台回调金额:{str(total_fee)}")
                 return self.write(wechat_pay_reponse.convert_response_xml("金额异常", False))
 
-            invoke_result_data = self.business_process_executing(self.request_params)
+            invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
                 return self.write(wechat_pay_reponse.convert_response_xml(invoke_result_data.error_message, False))
             self.business_process_executed(pay_order, response_result)
@@ -132,13 +130,12 @@ class WechatPayNotifyHandler(ClientBaseHandler):
             return self.write(wechat_pay_reponse.convert_response_xml("SUCCESS", True))
 
         except Exception as ex:
-            self.logging_link_error(str(ex) + "【微信支付异步通知】" + str(xml_params))
+            self.logging_link_error("【微信支付异步通知】" + str(ex) + ":" + str(xml_params))
             return self.write(wechat_pay_reponse.convert_response_xml("数据异常", False))
 
-    def business_process_executing(self, request_params):
+    def business_process_executing(self):
         """
         :description: 执行前事件
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -163,7 +160,7 @@ class WechatPayNotifyHandler(ClientBaseHandler):
             pay_order_model.update_entity(pay_order, "out_order_no,order_status,pay_date")
 
 
-class WechatRefundNotifyHandler(ClientBaseHandler):
+class WechatRefundNotifyHandler(FrameBaseHandler):
     """
     :description: 微信退款异步通知
     """
@@ -176,38 +173,33 @@ class WechatRefundNotifyHandler(ClientBaseHandler):
             wechat_refund_reponse = WeChatRefundReponse(xml_params)  # 创建对象
             response_result = wechat_refund_reponse.get_data()
             return_code = response_result["return_code"]
-            result_code = response_result["result_code"]
             if return_code == "FAIL":
                 return self.write(wechat_refund_reponse.convert_response_xml(response_result["return_msg"], False))
-            if result_code == "FAIL":
-                return self.write(wechat_refund_reponse.convert_response_xml(response_result["err_code_des"], False))
-            invoke_result_data = self.business_process_executing(self.request_params)
+            invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
                 return self.write(wechat_refund_reponse.convert_response_xml(invoke_result_data.error_message, False))
             # 解密
             req_info_dict = wechat_refund_reponse.decode_req_info(response_result["req_info"])
             req_info_dict = req_info_dict["root"]
-            self.business_process_executed(req_info_dict, self.request_params)
+            self.business_process_executed(req_info_dict)
             return self.write(wechat_refund_reponse.convert_response_xml("SUCCESS", True))
         except Exception as ex:
-            self.logging_link_error(str(ex) + "【微信退款异步通知】" + str(xml_params))
+            self.logging_link_error("【微信退款异步通知】" + str(ex)+":" + str(xml_params))
             return self.write(wechat_refund_reponse.convert_response_xml("数据异常", False))
 
-    def business_process_executing(self, request_params):
+    def business_process_executing(self):
         """
         :description: 执行前事件
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         return invoke_result_data
 
-    def business_process_executed(self, req_info_dict, request_params):
+    def business_process_executed(self, req_info_dict):
         """
         :description: 执行后事件
         :param req_info_dict: 退款解密信息
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -250,7 +242,7 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
         pay_order_no = self.get_param("pay_order_no")
         invoke_result_data = InvokeResultData()
 
-        if SevenHelper.is_continue_request(f"VoucherOrder_{str(user_id)}") == True:
+        if SevenHelper.is_continue_request(f"TiktokVoucherOrderHandler_{str(user_id)}") == True:
             return self.response_json_error("error", "对不起,请求太频繁")
         pay_order_model = PayOrderModel(context=self)
         pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
@@ -266,7 +258,7 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
         total_amount = pay_order.pay_amount
 
         try:
-            invoke_result_data = self.business_process_executing(self.request_params)
+            invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == True:
                 pay_notify_url = invoke_result_data.data["pay_notify_url"] if invoke_result_data.data.__contains__("pay_notify_url") else pay_notify_url
                 time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else 3600  #交易结束时间,设置1小时,单位秒
@@ -275,16 +267,15 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
             pay_order_model.update_table("out_order_no=%s", "pay_order_no=%s", params=[invoke_result_data.data["order_id"], pay_order_no])
-            invoke_result_data = self.business_process_executed(invoke_result_data, self.request_params)
+            invoke_result_data = self.business_process_executed(invoke_result_data)
             return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
             self.logging_link_error("【创建抖音预订单异常】" + str(ex))
             return self.response_json_error("fail", "请重新支付")
 
-    def business_process_executing(self, request_params):
+    def business_process_executing(self):
         """
         :description: 执行前事件
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -292,18 +283,17 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
         invoke_result_data.data = {}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data, request_params):
+    def business_process_executed(self, invoke_result_data):
         """
         :description: 执行后事件
         :param invoke_result_data: invoke_result_data
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
         return invoke_result_data
 
 
-class TiktokPayNotifyHandler(ClientBaseHandler):
+class TiktokPayNotifyHandler(FrameBaseHandler):
     """
     :description: 抖音支付异步通知
     """
@@ -321,9 +311,9 @@ class TiktokPayNotifyHandler(ClientBaseHandler):
             tiktok_reponse = TikTokReponse(json_params)
             response_result = tiktok_reponse.get_data()
             if tiktok_reponse.check_sign() != True:  # 校验签名,成功则继续后续操作
-                return self.write(tiktok_reponse.response_json(-1, "签名验证失败"))
+                return self.write(tiktok_reponse.convert_response_json(-1, "签名验证失败"))
             if response_result["type"] != "payment":
-                return self.write(tiktok_reponse.response_json(-1, "回调类型标记错误"))
+                return self.write(tiktok_reponse.convert_response_json(-1, "回调类型标记错误"))
             response_data = SevenHelper.json_loads(response_result["msg"])
             extra = SevenHelper.json_loads(response_data["extra"])
             total_fee = extra["share_amount"] if extra.__contains__("share_amount") else 0
@@ -331,27 +321,26 @@ class TiktokPayNotifyHandler(ClientBaseHandler):
             pay_order_model = PayOrderModel(context=self)
             pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
             if not pay_order:
-                return self.write(tiktok_reponse.response_json(-1, "未查询到支付订单信息"))
+                return self.write(tiktok_reponse.convert_response_json(-1, "未查询到支付订单信息"))
             # 判断金额是否匹配
             if int(decimal.Decimal(str(pay_order.pay_amount)) * 100) != int(total_fee):
                 self.logging_link_error(f"抖音支付订单[{pay_order_no}] 金额不匹配疑似刷单.数据库金额:{str(pay_order.pay_amount)} 平台回调金额:{str(total_fee)}")
-                return self.write(tiktok_reponse.response_json(-1, "金额异常"))
+                return self.write(tiktok_reponse.convert_response_json(-1, "金额异常"))
 
-            invoke_result_data = self.business_process_executing(self.request_params)
+            invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
-                return self.write(tiktok_reponse.response_json(-1, invoke_result_data.error_message))
+                return self.write(tiktok_reponse.convert_response_json(-1, invoke_result_data.error_message))
             self.business_process_executed(pay_order, response_data)
 
-            return self.write(tiktok_reponse.response_json())
+            return self.write(tiktok_reponse.convert_response_json())
 
         except Exception as ex:
-            self.logging_link_error(str(ex) + "【抖音支付异步通知】" + str(json_params))
-            return self.write(tiktok_reponse.response_json(-1, "数据异常"))
+            self.logging_link_error("【抖音支付异步通知】" + str(ex) +":"+ str(json_params))
+            return self.write(tiktok_reponse.convert_response_json(-1, "数据异常"))
 
-    def business_process_executing(self, request_params):
+    def business_process_executing(self):
         """
         :description: 执行前事件
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -381,7 +370,7 @@ class TiktokPayNotifyHandler(ClientBaseHandler):
             pay_order_model.update_entity(pay_order, "out_order_no,order_status,pay_date")
 
 
-class TiktokRefundNotifyHandler(ClientBaseHandler):
+class TiktokRefundNotifyHandler(FrameBaseHandler):
     """
     :description: 抖音退款异步通知
     """
@@ -394,30 +383,29 @@ class TiktokRefundNotifyHandler(ClientBaseHandler):
             tiktok_reponse = TikTokReponse(json_params)
             response_result = tiktok_reponse.get_data()
             if tiktok_reponse.check_sign() != True:  # 校验签名,成功则继续后续操作
-                return self.write(tiktok_reponse.response_json(-1, "签名验证失败"))
+                return self.write(tiktok_reponse.convert_response_json(-1, "签名验证失败"))
             if response_result["type"] != "refund":
-                return self.write(tiktok_reponse.response_json(-1, "回调类型标记错误"))
+                return self.write(tiktok_reponse.convert_response_json(-1, "回调类型标记错误"))
             response_data = SevenHelper.json_loads(response_result["msg"])
             cp_refundno = response_data["cp_refundno"]
             refund_order_model = RefundOrderModel(context=self)
             refund_order = refund_order_model.get_entity("refund_no=%s", params=[cp_refundno])
             if not refund_order:
-                return self.write(tiktok_reponse.response_json(-1, "未查询到退款订单信息"))
-            invoke_result_data = self.business_process_executing(self.request_params)
+                return self.write(tiktok_reponse.convert_response_json(-1, "未查询到退款订单信息"))
+            invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
-                return self.write(tiktok_reponse.response_json(-1, invoke_result_data.error_message))
+                return self.write(tiktok_reponse.convert_response_json(-1, invoke_result_data.error_message))
             self.business_process_executed(refund_order, response_data)
 
-            return self.write(tiktok_reponse.response_json())
+            return self.write(tiktok_reponse.convert_response_json())
 
         except Exception as ex:
-            self.logging_link_error(str(ex) + "【抖音退款异步通知】" + str(json_params))
-            return self.write(tiktok_reponse.response_json(-1, "数据异常"))
+            self.logging_link_error("【抖音退款异步通知】" + str(ex) + ":" + str(json_params))
+            return self.write(tiktok_reponse.convert_response_json(-1, "数据异常"))
 
-    def business_process_executing(self, request_params):
+    def business_process_executing(self):
         """
         :description: 执行前事件
-        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
