@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-30 17:37:20
+@LastEditTime: 2021-10-09 09:02:45
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -17,6 +17,7 @@ from urllib.parse import parse_qs, urlparse
 from seven_framework.redis import *
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.customize.cryptography_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
@@ -54,31 +55,23 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.json_loads(rep_str)
 
-    def base64_encode(self, source, encoding="utf-8"):
+    def base64_encrypt(self, source, encoding="utf-8"):
         """
         :Description: base64加密
         :param source: 需加密的字符串
         :return: 加密后的字符串
         :last_editors: HuangJianYi
         """
-        if not source.strip():
-            return ""
-        import base64
-        encode_string = str(base64.b64encode(source.encode(encoding=encoding)), 'utf-8')
-        return encode_string
+        return CryptographyHelper.base64_encrypt(source, encoding)
 
-    def base64_decode(self, source):
+    def base64_encrypt(self, source, encoding="utf-8"):
         """
         :Description: base64解密
         :param source: 需加密的字符串
         :return: 解密后的字符串
         :last_editors: HuangJianYi
         """
-        if not source.strip():
-            return ""
-        import base64
-        decode_string = str(base64.b64decode(source), 'utf-8')
-        return decode_string
+        return CryptographyHelper.base64_encrypt(source, encoding)
 
     def get_param(self, param_name, default="", strip=True):
         """
@@ -109,7 +102,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         response_encrypt = config.get_value("response_encrypt", False)
         if response_encrypt == True:
-            self.http_response("0" + self.base64_encode(self.json_dumps(rep_dic)))
+            self.http_response("0" + self.base64_encrypt(self.json_dumps(rep_dic)))
         else:
             self.http_response(self.json_dumps(rep_dic))
 
@@ -142,7 +135,7 @@ class FrameBaseHandler(BaseApiHandler):
 
         response_encrypt = config.get_value("response_encrypt", False)
         if response_encrypt == True:
-            self.http_reponse("0" + self.base64_encode(self.json_dumps(rep_dic)),log_extra_dict)
+            self.http_reponse("0" + self.base64_encrypt(self.json_dumps(rep_dic)), log_extra_dict)
         else:
             self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)
 
@@ -176,7 +169,7 @@ class FrameBaseHandler(BaseApiHandler):
         :description: 通用参数错误返回json结构
         :param desc: 返错误描述
         :return: 将dumps后的数据字符串返回给客户端
-        :last_editors: ChenXiaolei
+        :last_editors: HuangJianYi
         """
         self.response_common(False, None, "params error", "参数错误")
 
