@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-09-17 19:42:25
+@LastEditTime: 2021-10-09 11:00:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -204,7 +204,7 @@ class ActModuleListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"condition": "", "params": [], "order_by": "sort_index desc,id asc"}
+        invoke_result_data.data = {}
         return invoke_result_data
 
     def business_process_executed(self, page_list):
