@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-09-14 19:47:41
+@LastEditTime: 2021-10-09 11:32:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -142,13 +142,41 @@ class ActPrizeListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == True:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
+
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
-        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name,0, is_del, page_size, page_index, False)
-        page_info = PageInfo(page_index, page_size, total, page_list)
+        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, is_cache=False)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list))
         return self.response_json_success(page_info)
 
+    def business_process_executing(self):
+        """
+        :description: 执行前事件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        return invoke_result_data
+
+    def business_process_executed(self, page_list):
+        """
+        :description: 执行后事件
+        :param page_list:page_list
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return page_list
+
 
 class DeleteActPrizeHandler(ClientBaseHandler):
     """
