@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-09-30 18:12:41
+@LastEditTime: 2021-10-09 09:19:05
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -13,6 +13,8 @@ import random
 import datetime
 import re
 import ast
+from seven_cloudapp_frame.libs.customize.cryptography_helper import *
+
 
 class SevenHelper:
     """
@@ -265,18 +267,18 @@ class SevenHelper:
             return '%.2f' % float(size / 1000000000000) + 'TB'
 
     @classmethod
-    def get_random(self, num, many):
+    def get_random(self, length, num=1):
         """
         :description: 获取随机数
-        :param num：位数
-        :param many：个数
+        :param length：长度
+        :param num：个数
         :return: str
-        :last_editors: CaiYouBin
+        :last_editors: HuangJianYi
         """
         result = ""
-        for x in range(many):
+        for x in range(num):
             s = ""
-            for i in range(num):
+            for i in range(length):
                 # n=1 生成数字  n=2 生成字母
                 n = random.randint(1, 2)
                 if n == 1:
@@ -436,7 +438,7 @@ class SevenHelper:
         results = re.findall('\[em_(.*?)\]', text_str)
         if results:
             for item in results:
-                text_str = text_str.replace("[em_{0}]".format(item), self.base64_encode(item))
+                text_str = text_str.replace("[em_{0}]".format(item), CryptographyHelper.base64_encrypt(item, "utf-8"))
         return text_str
 
     @classmethod
@@ -454,7 +456,7 @@ class SevenHelper:
         for location, item_emoji in enumerate(text_str):
             if item_emoji in unicode_codes.UNICODE_EMOJI:
                 bytes_item_emoji = item_emoji.encode("utf-8")
-                emoji_base64 = self.base64_decode(bytes_item_emoji)
+                emoji_base64 = CryptographyHelper.base64_encrypt(bytes_item_emoji, "utf-8")
                 list_e[location] = "[em_" + emoji_base64 + "]"
 
         return "".join(list_e)
@@ -485,6 +487,7 @@ class SevenHelper:
             return json.loads(rep_str)
         except Exception as ex:
             return json.loads(self.json_dumps(rep_str))
+
     @classmethod
     def get_sub_table(self,object_id,sub_count=0):
         """
