@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-09-22 15:22:39
+@LastEditTime: 2021-09-28 15:46:54
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -615,7 +615,7 @@ class TikTokReponse(object):
         sign = CryptoHelper().sha1_encrypt(params_str)
         return sign
 
-    def response_json(self, err_no=0, err_tips="success"):
+    def convert_response_json(self, err_no=0, err_tips="success"):
         """
         :description: 获取通知的数据
         :return:
