@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-09-28 13:43:01
+@LastEditTime: 2021-10-08 14:18:36
 @LastEditors: HuangJianYi
 @Description: 
 """
+from time import strftime
 from requests_pkcs12 import post
 import requests
 from Crypto.Cipher import AES
@@ -228,17 +229,17 @@ class WeChatHelper:
         return "".join(strs)
 
     @classmethod
-    def get_sign(self, params):
+    def get_sign(self, params, api_key):
         """
         :description:生成sign拼接API密钥
+        :param api_key: api密钥
         :return: 
         :last_editors: HuangJianYi
         """
         string_a = WeChatHelper.key_value_url(params, False)
-        string_sign_temp = string_a + '&key=' + self.api_key  # APIKEY, API密钥，需要在商户后台设置
+        string_sign_temp = string_a + '&key=' + api_key  # APIKEY, API密钥，需要在商户后台设置
         sign = (hashlib.md5(string_sign_temp.encode("utf-8")).hexdigest()).upper()
-        params['sign'] = sign
-        return params
+        return sign
 
 
 class WeChatPayRequest(object):
@@ -265,7 +266,7 @@ class WeChatPayRequest(object):
         self.mch_id = mch_id if mch_id else pay_config["mch_id"]
         self.certificate_url = certificate_url if certificate_url else pay_config["certificate_url"]
 
-    def get_prepay_id(self, unifiedorder_url, params):
+    def get_prepay_id(self, unified_order_url, params):
         """
         :description: 获取预支付单号prepay_id
         :param unifiedorder_url：微信下单地址
@@ -280,8 +281,8 @@ class WeChatPayRequest(object):
         if prepay_id:
             invoke_result_data.data = prepay_id
             return invoke_result_data
-
-        respone = requests.post(unifiedorder_url, self.convert_request_xml(params), headers={'Content-Type': 'application/xml'})
+        params['sign'] = WeChatHelper.get_sign(params, self.api_key)
+        respone = requests.post(unified_order_url, self.convert_request_xml(params), headers={'Content-Type': 'application/xml'})
         response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
         if response_data['return_code'] == 'SUCCESS':
             if response_data['result_code'] == 'SUCCESS':
@@ -290,13 +291,13 @@ class WeChatPayRequest(object):
                 invoke_result_data.data = prepay_id
                 return invoke_result_data
             else:
-                self.logger_error.error("【预支付单号】" + SevenHelper.json_dumps(response_data))
+                self.logger_error.error("【预支付单号】" + str(response_data))
                 invoke_result_data.success = False
                 invoke_result_data.error_code="error"
                 invoke_result_data.error_message = response_data['err_code_des']
                 return invoke_result_data
         else:
-            self.logger_error.error("【预支付单号】" + SevenHelper.json_dumps(response_data))
+            self.logger_error.error("【预支付单号】" + str(response_data))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = response_data['return_msg']
@@ -341,8 +342,8 @@ class WeChatPayRequest(object):
             params['time_expire'] = str(time_expire)
 
         # 开发者调用支付统一下单API生成预交易单
-        unifiedorder_url = 'https://api.mch.weixin.qq.com/pay/unifiedorder'
-        invoke_result_data = self.get_prepay_id(unifiedorder_url, params)
+        unified_order_url = 'https://api.mch.weixin.qq.com/pay/unifiedorder'
+        invoke_result_data = self.get_prepay_id(unified_order_url, params)
         if invoke_result_data.success == False:
             return invoke_result_data
         prepay_id = invoke_result_data.data
@@ -350,7 +351,8 @@ class WeChatPayRequest(object):
         params['package'] = f"prepay_id={prepay_id}"
         params['timestamp'] = str(int(time.time()))
         sign_again_params = {'appId': params['appid'], 'nonceStr': params['nonce_str'], 'package': params['package'], 'signType': 'MD5', 'timeStamp': params['timestamp']}
-        invoke_result_data.data = WeChatHelper.get_sign(sign_again_params)
+        sign_again_params['sign'] = WeChatHelper.get_sign(sign_again_params, self.api_key)
+        invoke_result_data.data = sign_again_params
         return invoke_result_data  # 返回给app
 
     def query_order(self, pay_order_no="", transaction_id=""):
@@ -378,7 +380,7 @@ class WeChatPayRequest(object):
                 params['transaction_id'] = str(transaction_id)
             if pay_order_no != "":
                 params['out_trade_no'] = str(pay_order_no)
-
+            params['sign'] = WeChatHelper.get_sign(params, self.api_key)
             request_xml = self.convert_request_xml(params)
             queryorder_url = 'https://api.mch.weixin.qq.com/pay/orderquery'
             respone = requests.post(queryorder_url, request_xml, headers={'Content-Type': 'application/xml'})
@@ -413,6 +415,7 @@ class WeChatPayRequest(object):
                 'nonce_str': WeChatHelper.get_nonce_str(),
                 'out_trade_no': str(pay_order_no)
             }
+            params['sign'] = WeChatHelper.get_sign(params, self.api_key)
             request_xml = self.convert_request_xml(params)
             queryorder_url = 'https://api.mch.weixin.qq.com/pay/closeorder'
             respone = requests.post(queryorder_url, request_xml, headers={'Content-Type': 'application/xml'})
@@ -471,7 +474,7 @@ class WeChatPayRequest(object):
             'sign_type': 'MD5',
             'total_fee': int(decimal.Decimal(str(total_fee)) * 100),
         }
-        params = WeChatHelper.get_sign(params)
+        params['sign'] = WeChatHelper.get_sign(params, self.api_key)
         refund_url = 'https://api.mch.weixin.qq.com/secapi/pay/refund'
         respone = post(url=refund_url, data=self.convert_request_xml(params), headers={'Content-Type': 'application/xml'}, pkcs12_filename=self.certificate_url, pkcs12_password=self.mch_id)
         response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
@@ -480,13 +483,13 @@ class WeChatPayRequest(object):
                 invoke_result_data.data = response_data['refund_id']
                 return invoke_result_data
             else:
-                self.logger_error.error("【创建退款单】" + SevenHelper.json_dumps(response_data))
+                self.logger_error.error("【创建退款单】" + str(response_data))
                 invoke_result_data.success = False
                 invoke_result_data.error_code="error"
                 invoke_result_data.error_message = response_data['err_code_des']
                 return invoke_result_data
         else:
-            self.logger_error.error("【创建退款单】" + SevenHelper.json_dumps(response_data))
+            self.logger_error.error("【创建退款单】" + str(response_data))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = response_data['return_msg']
@@ -514,7 +517,7 @@ class WeChatPayRequest(object):
                 'out_refund_no': str(refund_no),
                 'sign_type': 'MD5'
             }
-            params = WeChatHelper.get_sign(params)
+            params['sign'] = WeChatHelper.get_sign(params, self.api_key)
             request_xml = self.convert_request_xml(params)
             queryrefund_url = 'https://api.mch.weixin.qq.com/pay/refundquery'
             respone = requests.post(queryrefund_url, request_xml, headers={'Content-Type': 'application/xml'})
@@ -534,12 +537,11 @@ class WeChatPayRequest(object):
         :return: 
         :last_editors: HuangJianYi
         """
-        params = WeChatHelper.get_sign(params)
         xml = "<xml>"
         for k, v in params.items():
             # v = v.encode('utf8')
             # k = k.encode('utf8')
-            xml += '<' + k + '>' + v + '</' + k + '>'
+            xml += '<' + k + '>' + str(v) + '</' + k + '>'
         xml += "</xml>"
         return xml.encode("utf-8")
 
@@ -564,7 +566,7 @@ class WeChatPayReponse(object):
         """
         params = dict(self.data)  # make a copy to save sign
         del params['sign']
-        sign = WeChatHelper.get_sign(params)  # 本地签名
+        sign = WeChatHelper.get_sign(params, self.api_key)  # 本地签名
         if self.data['sign'] == sign:
             return True
         return False
