@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-26 14:00:08
+@LastEditTime: 2021-09-29 17:00:07
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -23,7 +23,28 @@ class AssetBaseModel():
         self.context = context
         self.logging_link_error = logging_error
 
-    def _get_user_asset_id_md5(self, act_id, user_id, asset_type, asset_object_id):
+    def _add_onlyid_warn_stat(self,handler_name):
+        """
+        :description: 添加唯一标识预警拦截计数
+        :param handler_name：接口名称
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        if handler_name:
+            handler_name = str(handler_name).lower()
+            redis_init = SevenHelper.redis_init()
+            
+            hash_name_1 = f"warn_handler_list_{str(SevenHelper.get_now_int(fmt='%Y%m%d'))}"
+            hash_key_1 = f"handlername_{handler_name}"
+            if not redis_init.hexists(hash_name_1, hash_key_1):
+                redis_init.hset(hash_name_1,hash_key_1,SevenHelper.json_dumps({"app_id":'',"handler_name":handler_name}))
+                redis_init.expire(hash_name_1, 24 * 3600)
+            
+            hash_name_2 = f"{hash_name_1}:{hash_key_1}"
+            redis_init.hincrby(hash_name_2, str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M')), 1)
+            redis_init.expire(hash_name_2, 24 * 3600)
+  
+    def get_user_asset_id_md5(self, act_id, user_id, asset_type, asset_object_id):
         """
         :description: 生成用户资产唯一标识
         :param act_id：活动标识
@@ -37,7 +58,7 @@ class AssetBaseModel():
             return 0
         return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}")
 
-    def _get_asset_check_code(self, id_md5, asset_value, sign_key):
+    def get_asset_check_code(self, id_md5, asset_value, sign_key):
         """
         :description: 生成用户资产校验码
         :param 用户资产唯一标识
@@ -51,27 +72,6 @@ class AssetBaseModel():
             return ""
         return CryptoHelper.md5_encrypt(f"{id_md5}_{asset_value}", sign_key)
 
-    def _add_onlyid_warn_stat(self,handler_name):
-        """
-        :description: 添加唯一标识预警拦截计数
-        :param handler_name：接口名称
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        if  handler_name:
-            handler_name = str(handler_name).lower()
-            redis_init = SevenHelper.redis_init()
-            
-            hash_name_1 = f"warn_handler_list_{str(SevenHelper.get_now_int(fmt='%Y%m%d'))}"
-            hash_key_1 = f"handlername_{handler_name}"
-            if not redis_init.hexists(hash_name_1, hash_key_1):
-                redis_init.hset(hash_name_1,hash_key_1,SevenHelper.json_dumps({"app_id":'',"handler_name":handler_name}))
-                redis_init.expire(hash_name_1, 24 * 3600)
-            
-            hash_name_2 = f"{hash_name_1}:{hash_key_1}"
-            redis_init.hincrby(hash_name_2, str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M')), 1)
-            redis_init.expire(hash_name_2, 24 * 3600)
-            
     def update_user_asset(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, only_id="",handler_name="",request_code="", info_json={}):
         """
         :description: 变更资产
@@ -81,7 +81,7 @@ class AssetBaseModel():
         :param open_id：open_id
         :param user_nick：昵称
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
-        :param asset_value：修改资产值
+        :param asset_value：变动的资产值，算好差值传入
         :param asset_object_id：资产对象标识
         :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
         :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
@@ -109,7 +109,7 @@ class AssetBaseModel():
             invoke_result_data.error_message = "资产类型为价格档位,参数asset_object_id不能为空或等于0"
             return invoke_result_data
         asset_value = int(asset_value)
-        user_asset_id_md5 = self._get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
+        user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         if user_asset_id_md5 == 0:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -172,7 +172,7 @@ class AssetBaseModel():
                 user_asset.create_date = now_datetime
 
             user_asset.asset_value += asset_value
-            user_asset.asset_check_code = self._get_asset_check_code(user_asset_id_md5, user_asset.asset_value, app_id)
+            user_asset.asset_check_code = self.get_asset_check_code(user_asset_id_md5, user_asset.asset_value, app_id)
             user_asset.modify_date = now_datetime
 
             old_asset_inventory_id = 0
@@ -317,7 +317,7 @@ class AssetBaseModel():
             for user_asset_dict in user_asset_dict_list:
                 if user_asset_dict["app_id"] != str(app_id):
                     user_asset_dict["asset_value"] = 0
-                if self._get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
+                if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
                     user_asset_dict["asset_value"] = 0
         return user_asset_dict_list
 
@@ -336,12 +336,12 @@ class AssetBaseModel():
             return None
         sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
-        user_asset_id_md5 = self._get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
+        user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s",params=[user_asset_id_md5])
         if user_asset_dict:
             if user_asset_dict["app_id"] != str(app_id):
                 user_asset_dict["asset_value"] = 0
-            if self._get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
+            if self.get_asset_check_code(user_asset_dict["id_md5"], user_asset_dict["asset_value"], app_id) != user_asset_dict["asset_check_code"]:
                 user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
